@@ -1,10 +1,6 @@
 package Bio::ASN1::EntrezGene;
-BEGIN {
-  $Bio::ASN1::EntrezGene::AUTHORITY = 'cpan:BIOPERLML';
-}
-{
-  $Bio::ASN1::EntrezGene::VERSION = '1.70';
-}
+our $AUTHORITY = 'cpan:BIOPERLML';
+$Bio::ASN1::EntrezGene::VERSION = '1.72';
 use utf8;
 use strict;
 use warnings;
@@ -145,7 +141,7 @@ sub _parse
         elsif($data->{$id}) { $data->{$id} = [$data->{$id}, $value] } # hash value has a second terminal value now!
         else { $data->{$id} = $value } # the first terminal value
       }
-      elsif($self->{input} =~ /\G{/cg)
+      elsif($self->{input} =~ /\G\{/cg)
       {
         $self->{depth}++;
         push(@{$data->{$id}}, $self->_parse());
@@ -318,7 +314,7 @@ Bio::ASN1::EntrezGene - Regular expression-based Perl Parser for NCBI Entrez Gen
 
 =head1 VERSION
 
-version 1.70
+version 1.72
 
 =head1 SYNOPSIS
 
